@@ -24,7 +24,6 @@ test_that("can find topic in specified package", {
   grid_index <- topic_index("grid")
   expect_equal(find_rdname("grid", "unit"), "unit")
   expect_equal(find_rdname("grid", "DOESNOTEXIST"), NULL)
-  expect_warning(find_rdname("grid", "DOESNOTEXIST", TRUE), "Failed to find")
 })
 
 test_that("can find topic in attached packages", {
@@ -32,3 +31,8 @@ test_that("can find topic in attached packages", {
   expect_equal(find_rdname_attached("unit"), list(rdname = "unit", package = "grid"))
   expect_equal(find_rdname_attached("DOESNOTEXIST"), NULL)
 })
+
+test_that("doesn't error if 'attached' package not installed", {
+  local_options(downlit.attached = "uninstalled")
+  expect_equal(find_rdname_attached("foo"), NULL)
+})
